==> jc-1.4.0.tar.gz: javax/print/attribute/standard/JobKOctetsSupported.h <==
// public final class javax.print.attribute.standard.JobKOctetsSupported

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 918eb93a2f6dd324 javax_print_attribute_SetOfIntegerSyntax
// @dep_class e60f391fb965208b javax_print_attribute_standard_JobKOctetsSupported

// header file dependencies
// @dep_header javax_print_attribute_SetOfIntegerSyntax

#include "javax/print/attribute/SetOfIntegerSyntax.h"

#ifndef _JC_javax_print_attribute_standard_JobKOctetsSupported_H_
#define _JC_javax_print_attribute_standard_JobKOctetsSupported_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_JobKOctetsSupported$sub_refs	_jc_javax_print_attribute_standard_JobKOctetsSupported$sub_refs;
typedef struct _jc_javax_print_attribute_standard_JobKOctetsSupported$sub_nonrefs	_jc_javax_print_attribute_standard_JobKOctetsSupported$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobKOctetsSupported$refs	_jc_javax_print_attribute_standard_JobKOctetsSupported$refs;
typedef struct _jc_javax_print_attribute_standard_JobKOctetsSupported$nonrefs	_jc_javax_print_attribute_standard_JobKOctetsSupported$nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobKOctetsSupported$object	_jc_javax_print_attribute_standard_JobKOctetsSupported$object;

typedef struct _jc_javax_print_attribute_standard_JobKOctetsSupported$fields_struct	_jc_javax_print_attribute_standard_JobKOctetsSupported$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_JobKOctetsSupported$vmethods	_jc_javax_print_attribute_standard_JobKOctetsSupported$vmethods;
typedef const struct _jc_javax_print_attribute_standard_JobKOctetsSupported$vtable	_jc_javax_print_attribute_standard_JobKOctetsSupported$vtable;
typedef const struct _jc_javax_print_attribute_standard_JobKOctetsSupported$vtype	_jc_javax_print_attribute_standard_JobKOctetsSupported$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_JobKOctetsSupported$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24JobKOctetsSupported;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_JobKOctetsSupported$fields_struct _jc_javax_print_attribute_standard_JobKOctetsSupported$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_JobKOctetsSupported$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_javax_print_attribute_standard_JobKOctetsSupported$object *, jint, jint);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobKOctetsSupported$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_JobKOctetsSupported$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_JobKOctetsSupported$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_JobKOctetsSupported$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_JobKOctetsSupported$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_JobKOctetsSupported$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobKOctetsSupported$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_JobKOctetsSupported$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_JobKOctetsSupported$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_JobKOctetsSupported$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_JobKOctetsSupported$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_SetOfIntegerSyntax$vmethods	javax_print_attribute_SetOfIntegerSyntax;
	_jc_javax_print_attribute_standard_JobKOctetsSupported$vmethods	javax_print_attribute_standard_JobKOctetsSupported;
};

// Vtype
struct _jc_javax_print_attribute_standard_JobKOctetsSupported$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_JobKOctetsSupported$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobKOctetsSupported$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobKOctetsSupported$refs {
    _jc_javax_print_attribute_standard_JobKOctetsSupported$sub_refs	javax_print_attribute_standard_JobKOctetsSupported;
    _jc_javax_print_attribute_SetOfIntegerSyntax$sub_refs	javax_print_attribute_SetOfIntegerSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobKOctetsSupported$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobKOctetsSupported$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_SetOfIntegerSyntax$sub_nonrefs	javax_print_attribute_SetOfIntegerSyntax;
    _jc_javax_print_attribute_standard_JobKOctetsSupported$sub_nonrefs	javax_print_attribute_standard_JobKOctetsSupported;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_JobKOctetsSupported$object {
	_jc_javax_print_attribute_standard_JobKOctetsSupported$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_JobKOctetsSupported$vtype	*vtype;
	_jc_javax_print_attribute_standard_JobKOctetsSupported$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_JobKOctetsSupported$vtype _jc_javax_print_attribute_standard_JobKOctetsSupported$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_JobKOctetsSupported, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_JobKOctetsSupported$class_object;

#endif	/* _JC_javax_print_attribute_standard_JobKOctetsSupported_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/JobKOctetsSupported.h <==
// public final class javax.print.attribute.standard.JobKOctetsSupported

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 918eb93a2f6dd324 javax_print_attribute_SetOfIntegerSyntax
// @dep_class e60f391fb965208b javax_print_attribute_standard_JobKOctetsSupported

// header file dependencies
// @dep_header javax_print_attribute_SetOfIntegerSyntax

#include "javax/print/attribute/SetOfIntegerSyntax.h"

#ifndef _JC_javax_print_attribute_standard_JobKOctetsSupported_H_
#define _JC_javax_print_attribute_standard_JobKOctetsSupported_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_JobKOctetsSupported$sub_refs	_jc_javax_print_attribute_standard_JobKOctetsSupported$sub_refs;
typedef struct _jc_javax_print_attribute_standard_JobKOctetsSupported$sub_nonrefs	_jc_javax_print_attribute_standard_JobKOctetsSupported$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobKOctetsSupported$refs	_jc_javax_print_attribute_standard_JobKOctetsSupported$refs;
typedef struct _jc_javax_print_attribute_standard_JobKOctetsSupported$nonrefs	_jc_javax_print_attribute_standard_JobKOctetsSupported$nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobKOctetsSupported$object	_jc_javax_print_attribute_standard_JobKOctetsSupported$object;

typedef struct _jc_javax_print_attribute_standard_JobKOctetsSupported$fields_struct	_jc_javax_print_attribute_standard_JobKOctetsSupported$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_JobKOctetsSupported$vmethods	_jc_javax_print_attribute_standard_JobKOctetsSupported$vmethods;
typedef const struct _jc_javax_print_attribute_standard_JobKOctetsSupported$vtable	_jc_javax_print_attribute_standard_JobKOctetsSupported$vtable;
typedef const struct _jc_javax_print_attribute_standard_JobKOctetsSupported$vtype	_jc_javax_print_attribute_standard_JobKOctetsSupported$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_JobKOctetsSupported$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24JobKOctetsSupported;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_JobKOctetsSupported$fields_struct _jc_javax_print_attribute_standard_JobKOctetsSupported$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_JobKOctetsSupported$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_javax_print_attribute_standard_JobKOctetsSupported$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobKOctetsSupported$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_JobKOctetsSupported$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_JobKOctetsSupported$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_JobKOctetsSupported$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_JobKOctetsSupported$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_JobKOctetsSupported$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobKOctetsSupported$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_JobKOctetsSupported$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_JobKOctetsSupported$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_JobKOctetsSupported$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_JobKOctetsSupported$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_SetOfIntegerSyntax$vmethods	javax_print_attribute_SetOfIntegerSyntax;
	_jc_javax_print_attribute_standard_JobKOctetsSupported$vmethods	javax_print_attribute_standard_JobKOctetsSupported;
};

// Vtype
struct _jc_javax_print_attribute_standard_JobKOctetsSupported$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_JobKOctetsSupported$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobKOctetsSupported$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobKOctetsSupported$refs {
    _jc_javax_print_attribute_standard_JobKOctetsSupported$sub_refs	javax_print_attribute_standard_JobKOctetsSupported;
    _jc_javax_print_attribute_SetOfIntegerSyntax$sub_refs	javax_print_attribute_SetOfIntegerSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobKOctetsSupported$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobKOctetsSupported$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_SetOfIntegerSyntax$sub_nonrefs	javax_print_attribute_SetOfIntegerSyntax;
    _jc_javax_print_attribute_standard_JobKOctetsSupported$sub_nonrefs	javax_print_attribute_standard_JobKOctetsSupported;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_JobKOctetsSupported$object {
	_jc_javax_print_attribute_standard_JobKOctetsSupported$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_JobKOctetsSupported$vtype	*vtype;
	_jc_javax_print_attribute_standard_JobKOctetsSupported$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_JobKOctetsSupported$vtype _jc_javax_print_attribute_standard_JobKOctetsSupported$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_JobKOctetsSupported, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_JobKOctetsSupported$class_object;

#endif	/* _JC_javax_print_attribute_standard_JobKOctetsSupported_H_ */
